@@ -8,6 +8,7 @@ from electrum.i18n import languages
 from electrum_gui.kivy.i18n import _
 from electrum.plugins import run_hook
 from electrum.bitcoin import RECOMMENDED_FEE
+from electrum import coinchooser
 
 from choice_dialog import ChoiceDialog
 
@@ -47,7 +48,7 @@ Builder.load_string('''
 <SettingsDialog@Popup>
     id: settings
     title: _('Electrum Settings')
-    watching_only: False
+    disable_pin: False
     use_encryption: False
     BoxLayout:
         orientation: 'vertical'
@@ -65,8 +66,8 @@ Builder.load_string('''
                     action: partial(root.language_dialog, self)
                 CardSeparator
                 SettingsItem:
-                    status: 'watching-only' if root.watching_only else ('ON' if root.use_encryption else 'OFF')
-                    disabled: root.watching_only
+                    status: '' if root.disable_pin else ('ON' if root.use_encryption else 'OFF')
+                    disabled: root.disable_pin
                     title: _('PIN code') + ': ' + self.status
                     description: _("Change your PIN code.")
                     action: partial(root.change_password, self)
@@ -129,8 +130,8 @@ class SettingsDialog(Factory.Popup):
 
     def update(self):
         self.wallet = self.app.wallet
-        self.watching_only = self.wallet.is_watching_only()
-        self.use_encryption = self.wallet.use_encryption
+        self.disable_pin = self.wallet.is_watching_only() if self.wallet else True
+        self.use_encryption = self.wallet.use_encryption if self.wallet else False
 
     def get_language_name(self):
         return languages.get(self.config.get('language', 'en_UK'), '')
@@ -157,13 +158,12 @@ class SettingsDialog(Factory.Popup):
         self._unit_dialog.open()
 
     def coinselect_status(self):
-        return self.app.wallet.coin_chooser_name(self.app.electrum_config)
+        return coinchooser.get_name(self.app.electrum_config)
 
     def coinselect_dialog(self, item, dt):
         if self._coinselect_dialog is None:
-            from electrum import COIN_CHOOSERS
-            choosers = sorted(COIN_CHOOSERS.keys())
-            chooser_name = self.app.wallet.coin_chooser_name(self.config)
+            choosers = sorted(coinchooser.COIN_CHOOSERS.keys())
+            chooser_name = coinchooser.get_name(self.config)
             def cb(text):
                 self.config.set_key('coin_chooser', text)
                 item.status = text
