@@ -3,18 +3,25 @@
 # Electrum - lightweight Bitcoin client
 # Copyright (C) 2012 thomasv@gitorious
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# Permission is hereby granted, free of charge, to any person
+# obtaining a copy of this software and associated documentation files
+# (the "Software"), to deal in the Software without restriction,
+# including without limitation the rights to use, copy, modify, merge,
+# publish, distribute, sublicense, and/or sell copies of the Software,
+# and to permit persons to whom the Software is furnished to do so,
+# subject to the following conditions:
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# The above copyright notice and this permission notice shall be
+# included in all copies or substantial portions of the Software.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
+# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
+# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
@@ -75,39 +82,34 @@ class PayToEdit(ScanQRTextEdit):
         x, y = line.split(',')
         n = re.match('^SCRIPT\s+([0-9a-fA-F]+)$', x.strip())
         if n:
-            _type = 'script'
-            address = n.group(1).decode('hex')
+            script = str(n.group(1)).decode('hex')
             amount = self.parse_amount(y)
+            return bitcoin.TYPE_SCRIPT, script, amount
         else:
-            _type = 'address'
             address = self.parse_address(x)
             amount = self.parse_amount(y)
-        return _type, address, amount
-
+            return bitcoin.TYPE_ADDRESS, address, amount
 
     def parse_amount(self, x):
         p = pow(10, self.amount_edit.decimal_point())
-        return int( p * Decimal(x.strip()))
-
+        return int(p * Decimal(x.strip()))
 
     def parse_address(self, line):
         r = line.strip()
         m = re.match('^'+RE_ALIAS+'$', r)
-        address = m.group(2) if m else r
+        address = str(m.group(2) if m else r)
         assert bitcoin.is_address(address)
         return address
 
-
     def check_text(self):
         self.errors = []
         if self.is_pr:
             return
         # filter out empty lines
-        lines = filter( lambda x: x, self.lines())
+        lines = filter(lambda x: x, self.lines())
         outputs = []
         total = 0
         self.payto_address = None
-
         if len(lines) == 1:
             data = lines[0]
             if data.startswith("bitcoin:"):
@@ -123,12 +125,12 @@ class PayToEdit(ScanQRTextEdit):
 
         for i, line in enumerate(lines):
             try:
-                type, to_address, amount = self.parse_address_and_amount(line)
+                _type, to_address, amount = self.parse_address_and_amount(line)
             except:
                 self.errors.append((i, line.strip()))
                 continue
 
-            outputs.append((type, to_address, amount))
+            outputs.append((_type, to_address, amount))
             total += amount
 
         self.outputs = outputs
@@ -154,29 +156,19 @@ class PayToEdit(ScanQRTextEdit):
                 amount = self.amount_edit.get_amount()
             except:
                 amount = None
-            self.outputs = [('address', self.payto_address, amount)]
+            self.outputs = [(bitcoin.TYPE_ADDRESS, self.payto_address, amount)]
 
         return self.outputs[:]
 
-
     def lines(self):
-        return str(self.toPlainText()).split('\n')
-
+        return unicode(self.toPlainText()).split('\n')
 
     def is_multiline(self):
         return len(self.lines()) > 1
 
     def paytomany(self):
-        from electrum.i18n import _
         self.setText("\n\n\n")
         self.update_size()
-        msg = '\n'.join([
-            _('Enter a list of outputs in the \'Pay to\' field.'),
-            _('One output per line.'),
-            _('Format: address, amount.'),
-            _('You may load a CSV file using the file icon.')
-        ])
-        QMessageBox.warning(self, _('Pay to many'), msg, _('OK'))
 
     def update_size(self):
         docHeight = self.document().size().height()
